==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexsettingssearchurl.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qlayout.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlistview.h>

#include <klocale.h>
#include <kdialog.h>
#include <kmessagebox.h>

#include <settings.h>

#include "kbibtexsettingssearchurl.h"

KBibTeXSettingsSearchURL::KBibTeXSettingsSearchURL( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setupGUI();
}


KBibTeXSettingsSearchURL::~KBibTeXSettingsSearchURL()
{
    // nothing
}

void KBibTeXSettingsSearchURL::applyData()
{
    kbibtexsettings.searchURLs.clear();
    for ( QListViewItemIterator it( m_listviewSearchURLs ); it.current(); it++ )
    {
        Settings::SearchURL *searchURL = new Settings::SearchURL;
        searchURL->description = it.current() ->text( 0 );
        searchURL->url = it.current() ->text( 1 );
        kbibtexsettings.searchURLs.append( searchURL );
    }
}

void KBibTeXSettingsSearchURL::setData()
{
    m_listviewSearchURLs->clear();
    for ( Settings::SearchURL * searchURL = kbibtexsettings.searchURLs.first(); searchURL;searchURL = kbibtexsettings.searchURLs.next() )
    {
        new QListViewItem( m_listviewSearchURLs, searchURL->description, searchURL->url );
    }
}

void KBibTeXSettingsSearchURL::setupGUI()
{
    QLabel * label = NULL;
    QGridLayout * layout = new QGridLayout( this, 5, 3, 0, KDialog::marginHint() );

    m_lineeditName = new QLineEdit( this, "lineedit_name" );
    layout->addWidget( m_lineeditName, 0, 1 );
    label = new QLabel( i18n( "De&scription:" ), this );
    label->setBuddy( m_lineeditName );
    layout->addWidget( label, 0, 0 );

    m_lineeditSearchURL = new QLineEdit( this, "lineedit_searchurl" );
    layout->addWidget( m_lineeditSearchURL, 1, 1 );
    label = new QLabel( i18n( "&URL:" ), this );
    label->setBuddy( m_lineeditSearchURL );
    layout->addWidget( label, 1, 0 );

    m_pushbuttonAdd = new QPushButton( i18n( "Add" ), this );
    layout->addWidget( m_pushbuttonAdd, 0, 2 );
    m_pushbuttonAdd->setEnabled( FALSE );

    m_pushbuttonDelete = new QPushButton( i18n( "Dele&te" ), this );
    layout->addWidget( m_pushbuttonDelete, 2, 2 );
    m_pushbuttonDelete->setEnabled( FALSE );

    m_listviewSearchURLs = new QListView( this );
    layout->addMultiCellWidget( m_listviewSearchURLs, 2, 4, 1, 1 );
    m_listviewSearchURLs->setAllColumnsShowFocus ( TRUE );
    m_listviewSearchURLs->addColumn( i18n( "Description" ) );
    m_listviewSearchURLs->addColumn( i18n( "URL" ) );
    label = new QLabel( i18n( "&List:" ), this );
    label->setBuddy( m_listviewSearchURLs );
    layout->addWidget( label, 2, 0 );
    m_listviewSearchURLs->setResizeMode( QListView::LastColumn );
    m_listviewSearchURLs->setMinimumWidth( 384 );

    m_pushbuttonResetToDefaults = new QPushButton( i18n( "Reset" ), this );
    layout->addWidget( m_pushbuttonResetToDefaults, 3, 2 );

    connect( m_listviewSearchURLs, SIGNAL( clicked( QListViewItem* ) ), this, SLOT( slotListViewExecuted( QListViewItem* ) ) );
    connect( m_lineeditName, SIGNAL( textChanged( const QString& ) ), this, SLOT( slotUserNameChanged() ) );
    connect( m_pushbuttonAdd, SIGNAL( clicked() ), this, SLOT( slotPushButtonAddClicked() ) );
    connect( m_pushbuttonDelete, SIGNAL( clicked() ), this, SLOT( slotPushButtonDeleteClicked() ) );
    connect( m_pushbuttonResetToDefaults, SIGNAL( clicked() ), this, SLOT( slotResetToDefaults() ) );
}

void KBibTeXSettingsSearchURL::slotListViewExecuted( QListViewItem*item )
{
    if ( item != NULL )
    {
        m_lineeditName->setText( item->text( 0 ) );
        m_lineeditSearchURL->setText( item->text( 1 ) );
        m_pushbuttonDelete->setEnabled( TRUE );
    }
    else
    {
        m_lineeditName->setText( "" );
        m_lineeditSearchURL->setText( "" );
        m_pushbuttonDelete->setEnabled( FALSE );
    }

    slotUserNameChanged();
}

void KBibTeXSettingsSearchURL::slotUserNameChanged( )
{
    m_pushbuttonAdd->setEnabled( !m_lineeditName->text().isEmpty() && !m_lineeditSearchURL->text().isEmpty() );
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );
    m_pushbuttonDelete->setEnabled( item != NULL );
    m_pushbuttonAdd->setText( item != NULL ? i18n( "App&ly" ) : i18n( "Add" ) );
    if ( item != NULL )
        m_listviewSearchURLs->setSelected( item, TRUE );
}

void KBibTeXSettingsSearchURL::slotPushButtonAddClicked()
{
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );

    if ( item != NULL )
    {
        item->setText( 0, m_lineeditName->text() );
        item->setText( 1, m_lineeditSearchURL->text() );
    }
    else
        m_listviewSearchURLs->setSelected( new QListViewItem( m_listviewSearchURLs, m_listviewSearchURLs->lastItem(), m_lineeditName->text(), m_lineeditSearchURL->text() ), TRUE );

    emit configChanged();
}

void KBibTeXSettingsSearchURL::slotPushButtonDeleteClicked()
{
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );

    if ( item != NULL )
    {
        m_listviewSearchURLs->removeItem( item );
        m_lineeditName->setText( "" );
        m_lineeditSearchURL->setText( "" );
        emit configChanged();
    }
}

void KBibTeXSettingsSearchURL::slotResetToDefaults()
{
    if ( KMessageBox::questionYesNo( this, i18n( "Reset all search URLs to default values? All modifications will be lost." ), i18n( "Reset to default" ) ) == KMessageBox::Yes )
    {
        kbibtexsettings.setDefaultSearchURLs();
        setData();
    }
}

#include "kbibtexsettingssearchurl.moc"

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/kbibtexsettingssearchurl.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qlayout.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlistview.h>

#include <klocale.h>
#include <kdialog.h>
#include <kmessagebox.h>

#include <settings.h>

#include "kbibtexsettingssearchurl.h"

KBibTeXSettingsSearchURL::KBibTeXSettingsSearchURL( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setupGUI();
}


KBibTeXSettingsSearchURL::~KBibTeXSettingsSearchURL()
{
    // nothing
}

void KBibTeXSettingsSearchURL::applyData()
{
    KBibTeX::kbibtexsettings.searchURLs.clear();
    for ( QListViewItemIterator it( m_listviewSearchURLs ); it.current(); it++ )
    {
        KBibTeX::Settings::SearchURL *searchURL = new KBibTeX::Settings::SearchURL;
        searchURL->description = it.current() ->text( 0 );
        searchURL->url = it.current() ->text( 1 );
        KBibTeX::kbibtexsettings.searchURLs.append( searchURL );
    }
}

void KBibTeXSettingsSearchURL::setData()
{
    m_listviewSearchURLs->clear();
    for ( KBibTeX::Settings::SearchURL * searchURL = KBibTeX::kbibtexsettings.searchURLs.first(); searchURL;searchURL = KBibTeX::kbibtexsettings.searchURLs.next() )
    {
        new QListViewItem( m_listviewSearchURLs, searchURL->description, searchURL->url );
    }
}

void KBibTeXSettingsSearchURL::setupGUI()
{
    QLabel * label = NULL;
    QGridLayout * layout = new QGridLayout( this, 5, 3, 0, KDialog::marginHint() );

    m_lineeditName = new QLineEdit( this, "lineedit_name" );
    layout->addWidget( m_lineeditName, 0, 1 );
    label = new QLabel( i18n( "De&scription:" ), this );
    label->setBuddy( m_lineeditName );
    layout->addWidget( label, 0, 0 );

    m_lineeditSearchURL = new QLineEdit( this, "lineedit_searchurl" );
    layout->addWidget( m_lineeditSearchURL, 1, 1 );
    label = new QLabel( i18n( "&URL:" ), this );
    label->setBuddy( m_lineeditSearchURL );
    layout->addWidget( label, 1, 0 );

    m_pushbuttonAdd = new QPushButton( i18n( "Add" ), this );
    layout->addWidget( m_pushbuttonAdd, 0, 2 );
    m_pushbuttonAdd->setEnabled( FALSE );

    m_pushbuttonDelete = new QPushButton( i18n( "Dele&te" ), this );
    layout->addWidget( m_pushbuttonDelete, 2, 2 );
    m_pushbuttonDelete->setEnabled( FALSE );

    m_listviewSearchURLs = new QListView( this );
    layout->addMultiCellWidget( m_listviewSearchURLs, 2, 4, 1, 1 );
    m_listviewSearchURLs->setAllColumnsShowFocus ( TRUE );
    m_listviewSearchURLs->addColumn( i18n( "Description" ) );
    m_listviewSearchURLs->addColumn( i18n( "URL" ) );
    label = new QLabel( i18n( "&List:" ), this );
    label->setBuddy( m_listviewSearchURLs );
    layout->addWidget( label, 2, 0 );
    m_listviewSearchURLs->setResizeMode( QListView::LastColumn );
    m_listviewSearchURLs->setMinimumWidth( 384 );

    m_pushbuttonResetToDefaults = new QPushButton( i18n( "Reset" ), this );
    layout->addWidget( m_pushbuttonResetToDefaults, 3, 2 );

    connect( m_listviewSearchURLs, SIGNAL( clicked( QListViewItem* ) ), this, SLOT( slotListViewExecuted( QListViewItem* ) ) );
    connect( m_lineeditName, SIGNAL( textChanged( const QString& ) ), this, SLOT( slotUserNameChanged() ) );
    connect( m_pushbuttonAdd, SIGNAL( clicked() ), this, SLOT( slotPushButtonAddClicked() ) );
    connect( m_pushbuttonDelete, SIGNAL( clicked() ), this, SLOT( slotPushButtonDeleteClicked() ) );
    connect( m_pushbuttonResetToDefaults, SIGNAL( clicked() ), this, SLOT( slotResetToDefaults() ) );
}

void KBibTeXSettingsSearchURL::slotListViewExecuted( QListViewItem*item )
{
    if ( item != NULL )
    {
        m_lineeditName->setText( item->text( 0 ) );
        m_lineeditSearchURL->setText( item->text( 1 ) );
        m_pushbuttonDelete->setEnabled( TRUE );
    }
    else
    {
        m_lineeditName->setText( "" );
        m_lineeditSearchURL->setText( "" );
        m_pushbuttonDelete->setEnabled( FALSE );
    }

    slotUserNameChanged();
}

void KBibTeXSettingsSearchURL::slotUserNameChanged( )
{
    m_pushbuttonAdd->setEnabled( !m_lineeditName->text().isEmpty() && !m_lineeditSearchURL->text().isEmpty() );
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );
    m_pushbuttonDelete->setEnabled( item != NULL );
    m_pushbuttonAdd->setText( item != NULL ? i18n( "App&ly" ) : i18n( "Add" ) );
    if ( item != NULL )
        m_listviewSearchURLs->setSelected( item, TRUE );
}

void KBibTeXSettingsSearchURL::slotPushButtonAddClicked()
{
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );

    if ( item != NULL )
    {
        item->setText( 0, m_lineeditName->text() );
        item->setText( 1, m_lineeditSearchURL->text() );
    }
    else
        m_listviewSearchURLs->setSelected( new QListViewItem( m_listviewSearchURLs, m_listviewSearchURLs->lastItem(), m_lineeditName->text(), m_lineeditSearchURL->text() ), TRUE );

    emit configChanged();
}

void KBibTeXSettingsSearchURL::slotPushButtonDeleteClicked()
{
    QListViewItem * item = m_listviewSearchURLs->findItem( m_lineeditName->text(), 0 );

    if ( item != NULL )
    {
        m_listviewSearchURLs->removeItem( item );
        m_lineeditName->setText( "" );
        m_lineeditSearchURL->setText( "" );
        emit configChanged();
    }
}

void KBibTeXSettingsSearchURL::slotResetToDefaults()
{
    KBibTeX::kbibtexsettings.readdDefaultSearchURLs();
    setData();
}

#include "kbibtexsettingssearchurl.moc"
